//
//  QuartzFun.swift
//  CoreG.PlusControls
//
//  Created by new on 12/17/14.
//  Copyright (c) 2014 Avi Pogrow. All rights reserved.
//
import UIKit

//////////////////////////////////////////////////////////////////
 // The data structure for the different shapes segmented control///
 ////////////////////////////////////////////////////////////////
enum Shape: UInt {
   case Line = 0, Rect, Ellipse, Image
 }

 //////////////////////////////////////////////////////
 // The data structure for the different Colors segmented control
 //////////////////////////////////////////////////////
 enum DrawingColor: UInt {
   case Red = 0, Blue, Yellow, Green, Random
 }

///////////////////////////////////////////////////
// extension of UIColor Class////////////////////
////**** adds the method of selecting a random color***
///////////////////////////////////////////////////////
extension UIColor {
	
class func randomColor() -> UIColor {
	
	   let red = CGFloat(Double((arc4random() % 256))/255)
	   let green = CGFloat(Double((arc4random() % 256))/255)
	   let blue = CGFloat(Double((arc4random() % 256))/255)
		
	   return UIColor(red: red, green: green, blue: blue, alpha:1.0)
	 
	 }
}
////******************//////////////
// *********custom UIView class************///
////////////////////////////////////////

class QuartzFunView: UIView {
////Two Sets of Properties///////////
/////////////////////////////////////////
// 1.  Application - settable properties/////
////////*** These properties will be used by the View Controller****////////

var shape = Shape.Line // keeps track of what shape the  user wants to draw
var currentColor = UIColor.redColor()//////The user's selected color
var useRandomColor = false

///////////////////////////////////////////////////////////
// 2. Internal properties that will be used inside this file//
//////////////////////////////////////////////////////////
private let image = UIImage(named:"iphone")!
private var firstTouchLocation:CGPoint = CGPointZero
private var lastTouchLocation:CGPoint = CGPointZero
private var redrawRect:CGRect = CGRectZero
//////////////////////////////////////////////////////////////////
///////collecting and storing the touch data from the user
/////////this tells us where to start and end the drawing//////////
/////////////////////////////////////////////////////////////////
override func touchesBegan(touches: NSSet, withEvent event:UIEvent) {
   if useRandomColor {
      currentColor = UIColor.randomColor()
       }
let touch = touches.anyObject() as UITouch
firstTouchLocation = touch.locationInView(self)
  let lastTouchLocation = firstTouchLocation
setNeedsDisplay()
}
override func touchesMoved(touches: NSSet, withEvent event: UIEvent){
    let touch = touches.anyObject() as UITouch
	lastTouchLocation = touch.locationInView(self)
	setNeedsDisplay()
}
override func touchesEnded(touches: NSSet, withEvent event: UIEvent){
    let touch = touches.anyObject() as UITouch
	let lastTouchLocation = touch.locationInView(self)
	setNeedsDisplay()
   }
/////////////////////////////////////////////////////////////////////
/////code that draws the different shapes////////////
/// based on the shape selection of the user/////////////
///////////////////////////////////////////////////////////////////
 func currentRect() -> CGRect {
   return CGRectMake(firstTouchLocation.x,
    firstTouchLocation.y,
    lastTouchLocation.x - firstTouchLocation.x,
	lastTouchLocation.y - firstTouchLocation.y)
 }

override func drawRect(rect: CGRect) {
    let context = UIGraphicsGetCurrentContext()
	CGContextSetLineWidth(context, 2.0)
	CGContextSetStrokeColorWithColor(context, currentColor.CGColor)
	CGContextSetFillColorWithColor(context, currentColor.CGColor)
	
	switch shape {
	   case .Line:
	      CGContextMoveToPoint(context, firstTouchLocation.x,
										firstTouchLocation.y)
		  CGContextAddLineToPoint(context, lastTouchLocation.x,
		                                    lastTouchLocation.y)
		  CGContextStrokePath(context)
		
		case .Rect:
		  CGContextAddRect(context, currentRect())
		  CGContextDrawPath(context, kCGPathFillStroke)
		break
		
		case .Ellipse:
		  CGContextAddEllipseInRect(context, currentRect())
		  CGContextDrawPath(context, kCGPathFillStroke)
		break
		
		case .Image:
		  let horizontalOffset = image.size.width / 2
		  let verticalOffset = image.size.height / 2
		  let drawPoint =
		      CGPointMake(lastTouchLocation.x - horizontalOffset,
			               lastTouchLocation.y - verticalOffset)
		 image.drawAtPoint(drawPoint)
		
	     }
	}

}



 